@@ -25,20 +25,16 @@ import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
-import java.security.AccessController;
-import java.security.PrivilegedActionException;
-import java.security.PrivilegedExceptionAction;
 import java.util.ArrayList;
 import java.util.List;
 
-import javax.servlet.ServletContext;
+import jakarta.servlet.ServletContext;
 
 import org.apache.catalina.Context;
 import org.apache.catalina.LifecycleException;
 import org.apache.catalina.LifecycleState;
 import org.apache.catalina.Loader;
 import org.apache.catalina.Session;
-import org.apache.catalina.security.SecurityUtil;
 import org.apache.catalina.util.CustomObjectInputStream;
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
@@ -47,7 +43,7 @@ import org.apache.tomcat.util.ExceptionUtils;
 /**
  * Standard implementation of the <b>Manager</b> interface that provides simple session persistence across restarts of
  * this component (such as when the entire server is shut down and restarted, or when a particular web application is
- * reloaded).
+ * reloaded.
  * <p>
  * <b>IMPLEMENTATION NOTE</b>: Correct behavior of session storing and reloading depends upon external calls to the
  * <code>start()</code> and <code>stop()</code> methods of this class at the correct times.
@@ -58,36 +54,6 @@ public class StandardManager extends ManagerBase {
 
     private final Log log = LogFactory.getLog(StandardManager.class); // must not be static
 
-    // ---------------------------------------------------- Security Classes
-
-    private class PrivilegedDoLoad implements PrivilegedExceptionAction<Void> {
-
-        PrivilegedDoLoad() {
-            // NOOP
-        }
-
-        @Override
-        public Void run() throws Exception {
-            doLoad();
-            return null;
-        }
-    }
-
-    private class PrivilegedDoUnload implements PrivilegedExceptionAction<Void> {
-
-        PrivilegedDoUnload() {
-            // NOOP
-        }
-
-        @Override
-        public Void run() throws Exception {
-            doUnload();
-            return null;
-        }
-
-    }
-
-
     // ----------------------------------------------------- Instance Variables
 
     /**
@@ -100,9 +66,9 @@ public class StandardManager extends ManagerBase {
      * Path name of the disk file in which active sessions are saved when we stop, and from which these sessions are
      * loaded when we start. A <code>null</code> value indicates that no persistence is desired. If this pathname is
      * relative, it will be resolved against the temporary working directory provided by our context, available via the
-     * <code>javax.servlet.context.tempdir</code> context attribute.
+     * <code>jakarta.servlet.context.tempdir</code> context attribute.
      */
-    protected String pathname = "SESSIONS.ser";
+    protected String pathname = null;
 
 
     // ------------------------------------------------------------- Properties
@@ -138,34 +104,6 @@ public class StandardManager extends ManagerBase {
 
     @Override
     public void load() throws ClassNotFoundException, IOException {
-        if (SecurityUtil.isPackageProtectionEnabled()) {
-            try {
-                AccessController.doPrivileged(new PrivilegedDoLoad());
-            } catch (PrivilegedActionException ex) {
-                Exception exception = ex.getException();
-                if (exception instanceof ClassNotFoundException) {
-                    throw (ClassNotFoundException) exception;
-                } else if (exception instanceof IOException) {
-                    throw (IOException) exception;
-                }
-                if (log.isDebugEnabled()) {
-                    log.debug("Unreported exception in load() ", exception);
-                }
-            }
-        } else {
-            doLoad();
-        }
-    }
-
-
-    /**
-     * Load any currently active sessions that were previously unloaded to the appropriate persistence mechanism, if
-     * any. If persistence is not supported, this method returns without doing anything.
-     *
-     * @exception ClassNotFoundException if a serialized class cannot be found during the reload
-     * @exception IOException            if an input/output error occurs
-     */
-    protected void doLoad() throws ClassNotFoundException, IOException {
         if (log.isTraceEnabled()) {
             log.trace("Start: Loading persisted sessions");
         }
@@ -181,9 +119,9 @@ public class StandardManager extends ManagerBase {
         if (log.isTraceEnabled()) {
             log.trace(sm.getString("standardManager.loading", pathname));
         }
-        Loader loader;
+        Loader loader = null;
         ClassLoader classLoader = null;
-        Log logger;
+        Log logger = null;
         try (FileInputStream fis = new FileInputStream(file.getAbsolutePath());
                 BufferedInputStream bis = new BufferedInputStream(fis)) {
             Context c = getContext();
@@ -229,7 +167,7 @@ public class StandardManager extends ManagerBase {
             }
         } catch (FileNotFoundException e) {
             if (log.isDebugEnabled()) {
-                log.debug(sm.getString("standardManager.noFile", file.getAbsolutePath()), e);
+                log.debug(sm.getString("standardManager.noFile", file.getAbsolutePath()));
             }
             return;
         }
@@ -242,32 +180,6 @@ public class StandardManager extends ManagerBase {
 
     @Override
     public void unload() throws IOException {
-        if (SecurityUtil.isPackageProtectionEnabled()) {
-            try {
-                AccessController.doPrivileged(new PrivilegedDoUnload());
-            } catch (PrivilegedActionException ex) {
-                Exception exception = ex.getException();
-                if (exception instanceof IOException) {
-                    throw (IOException) exception;
-                }
-                if (log.isDebugEnabled()) {
-                    log.debug("Unreported exception in unLoad()", exception);
-                }
-            }
-        } else {
-            doUnload();
-        }
-    }
-
-
-    /**
-     * Save any currently active sessions in the appropriate persistence mechanism, if any. If persistence is not
-     * supported, this method returns without doing anything.
-     *
-     * @exception IOException if an input/output error occurs
-     */
-    protected void doUnload() throws IOException {
-
         if (log.isTraceEnabled()) {
             log.trace(sm.getString("standardManager.unloading.debug"));
         }
@@ -377,7 +289,7 @@ public class StandardManager extends ManagerBase {
         }
 
         // Expire all active sessions
-        Session[] sessions = findSessions();
+        Session sessions[] = findSessions();
         for (Session session : sessions) {
             try {
                 if (session.isValid()) {
@@ -405,7 +317,7 @@ public class StandardManager extends ManagerBase {
      * @return the file
      */
     protected File file() {
-        if (pathname == null || pathname.isEmpty()) {
+        if (pathname == null || pathname.length() == 0) {
             return null;
         }
         File file = new File(pathname);
